/*
 *  LibRoadnav
 *  MapControlDataImporter_GPX.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Imports GPX data into the Roadnav tile-layers and waypoints
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPCONTROLDATAIMPORTER_GPX_H
#define MAPCONTROLDATAIMPORTER_GPX_H

#include <wx/datetime.h>

#include "Constants.h"
#include "Point.h"
#include "MapControlDataEntry_Std.h"
#include "MapControlData.h"
#include "MapControlDataImporter.h"
#include "MapMarker.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Imports GPX data into the Roadnav tile-layers and waypoints
///
//////////////////////////////////////////////////////////////////////////////
class MapControlDataImporter_GPX : public MapControlDataImporter
{
	public: // public functions
		MapControlDataImporter_GPX();
		virtual ~MapControlDataImporter_GPX();
	
		virtual IMapControlDataEntry * GetRecord(wxUint32 iIndex);
		virtual int Count();

		virtual MapMarker * GetMarker(wxUint32 iIndex);
		virtual int MarkerCount();

		bool Load(wxString strFilename, IMapControlData * pMapControlData, ProgressDialog * pdlgProgress, int iProgressStart, int iProgressTicks, Point * ptCenter, ERecordType eDefaultType);

	private: // private functions
		void Clear();

	private: // private member variables

		/// the records themselves
		MapControlDataEntry_Std * m_psRecords;

		/// the number of records
		int m_nRecords;


		/// the markers themselves
		MapMarker * m_pcMarkers;

		/// the number of markers
		wxUint32 m_nMarkers;
		
};

#endif
