/*
 *  LibRoadnav
 *  MapLookup.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Looks up addresses or finds the closest address to a set of coordinates.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPLOOKUP_H
#define MAPLOOKUP_H

#include <vector>

#include "Constants.h"
#include "Point.h"
#include "MapControlData.h"
#include "Address.h"
#include "AutoComplete.h"

Address FindAddress(int iSearchNumber, const wxString & strSearchStreet, const wxString & strSearchType, const wxString & strCity, const wxString & strState, const bool * pbVisibility, IMapControlData * pDataForced = NULL);
Address FindAddress(const wxString & strSearchFullStreet, const wxString & strCity, const wxString & strState, const bool * pbVisibility, IMapControlData * pDataForced = NULL, wxString * pstrErrorMsg = NULL, wxString * pstrSuggestedStreet = NULL, wxString * pstrSuggestedCity = NULL, wxString * pstrSuggestedState = NULL);

Address FindCoordinates(const Point & ptSearch, const bool * pbVisibility, bool bRegionMode = false, bool bUseCoordFromRec = false, IMapControlData * pDataForced = NULL);

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Autocompletes a street address
///
//////////////////////////////////////////////////////////////////////////////
class AutoComplete_Street : public IAutoComplete
{
	public:
		AutoComplete_Street();
		void SetState(const wxString & strState);
		void SetCity(const wxString & strCity);
		void SetVisibility(const bool * pbVisibility);
		virtual wxString ClosestMatch(const wxString & strInput);
		virtual int GetUpdateDelay();
	
	private:
		wxString m_strState;
		wxString m_strCity;
		bool m_bVisibility[LAST_RECORD_TYPE + 1];
};

#endif
